@@ -5,7 +5,7 @@ use warnings;
 
 use base 'ObjectDB::Meta::Relationship';
 
-our $VERSION = '3.11';
+our $VERSION = '3.12';
 
 sub type     { 'many to one' }
 sub is_multi { 0 }
@@ -15,12 +15,16 @@ sub to_source {
     my (%options) = @_;
 
     my $name      = $self->name;
+    my $name_prefix = $options{name_prefix} || '';
     my $table     = $options{table} || $self->orig_class->meta->table;
     my $rel_table = $self->class->meta->table;
 
     my ($from, $to) = %{$self->{map}};
 
-    my $constraint = ["$table.$from" => {-col => "$name.$to"}];
+    my $constraint = [
+        "$table.$from" => {-col => "$name_prefix$name.$to"},
+        @{$self->{constraint} || []}
+    ];
 
     my @columns;
     if ($options{columns}) {
