@@ -5,7 +5,7 @@ use warnings;
 
 use base 'ObjectDB::Meta::Relationship';
 
-our $VERSION = '3.11';
+our $VERSION = '3.12';
 
 require Carp;
 
@@ -22,7 +22,8 @@ sub to_source {
 
     my ($from, $to) = %{$self->{map}};
 
-    my $constraint = ["$table.$from" => {-col => "$name.$to"}];
+    my $constraint =
+      ["$table.$from" => {-col => "$name.$to"}, @{$self->{constraint} || []}];
 
     my @columns;
     if ($options{columns}) {
