@@ -3,7 +3,7 @@ package ObjectDB::Quoter;
 use strict;
 use warnings;
 
-our $VERSION = '3.11';
+our $VERSION = '3.12';
 
 use base 'SQL::Composer::Quoter';
 
@@ -32,7 +32,7 @@ sub quote {
     foreach my $part (@parts) {
         my $relationship = $meta->get_relationship($part);
 
-        $name      = $relationship->name;
+        $name = $name ? $name . '_' . $relationship->name : $relationship->name;
         $rel_table = $relationship->class->meta->table;
         $meta      = $relationship->class->meta;
     }
